@@ -9,14 +9,13 @@ try:
 except ImportError:
     better_exceptions_installed = False
 from covsirphy.__version__ import __version__
-from covsirphy.analysis import ODESimulator, ChangeFinder
-from covsirphy.analysis import PhaseSeries, Scenario, ExampleData
 from covsirphy.cleaning import Term, CleaningBase, DataLoader
-from covsirphy.cleaning import JHUData
-from covsirphy.cleaning import CountryData, PopulationData, OxCGRTData
+from covsirphy.cleaning import JHUData, CountryData, PopulationData, OxCGRTData
 from covsirphy.ode import ModelBase, SIR, SIRD, SIRF, SIRFV, SEWIRF
-from covsirphy.phase import Estimator, Trend
+from covsirphy.phase import Trend, ChangeFinder, PhaseSeries
+from covsirphy.simulation import Optimizer, ODESimulator, Estimator
 from covsirphy.util import line_plot, jpn_map, StopWatch, error
+from covsirphy.analysis import ExampleData, Scenario
 # Deprecated
 from covsirphy.cleaning import Population, Word
 
@@ -34,7 +33,7 @@ __all__ = [
     "Term", "CleaningBase", "DataLoader",
     "JHUData", "CountryData", "PopulationData", "OxCGRTData",
     "ModelBase", "SIR", "SIRD", "SIRF", "SIRFV", "SEWIRF",
-    "Estimator", "Trend",
+    "Estimator", "Trend", "Optimizer",
     "line_plot", "jpn_map", "StopWatch", "error",
     # Deprecated
     "Population", "Word",
