@@ -48,7 +48,7 @@ class Scenario(Term):
         self.province = province or self.UNKNOWN
         self.area = JHUData.area_name(country, province)
         # First/last date of the area
-        df = jhu_data.subset(country=country, province=province)
+        df = jhu_data.subset(country=country, province=self.province)
         self.first_date = df[self.DATE].min().strftime(self.DATE_FORMAT)
         self.last_date = df[self.DATE].max().strftime(self.DATE_FORMAT)
         # Init
@@ -128,6 +128,7 @@ class Scenario(Term):
             - If @model is None, the model of the last phase will be used.
             - Tau will be fixed as the last phase's value.
             - kwargs: Default values are the parameter values of the last phase.
+            - If @end_date and @days are None, the end date will be the last date of the records.
         """
         # Parse arguments
         name = self.MAIN if name == "Main" else name
@@ -137,11 +138,12 @@ class Scenario(Term):
         start_date = self.series_dict[name].next_date()
         if end_date is None:
             if days is None:
-                raise NameError("@end_date or @days must be specified.")
-            if not isinstance(days, int):
+                end_date = self.last_date
+            elif not isinstance(days, int):
                 raise TypeError("@days must be an integer.")
-            end_obj = self.date_obj(start_date) + timedelta(days=days)
-            end_date = end_obj.strftime(self.DATE_FORMAT)
+            else:
+                end_obj = self.date_obj(start_date) + timedelta(days=days)
+                end_date = end_obj.strftime(self.DATE_FORMAT)
         population = population or self.population
         summary_df = self.series_dict[name].summary()
         if model is None:
@@ -185,6 +187,22 @@ class Scenario(Term):
             self.series_dict[name] = copy.deepcopy(self.series_dict[self.MAIN])
         self.series_dict[name].clear(include_past=include_past)
 
+    def remove(self, name="Main"):
+        """
+        Remove phase information.
+
+        Args:
+            name (str): phase series name
+                - if 'Main', main phase series will be used
+                - if not registered, new phaseseries will be created
+            include_past (bool):
+                - if True, include past phases.
+                - future phase are always included
+        """
+        self.clear(name=name, include_past=True)
+        # Delete 0th phase
+        self.series_dict[name].delete(phase="0th")
+
     def summary(self, name=None):
         """
         Summarize the series of phases and return a dataframe.
@@ -231,7 +249,7 @@ class Scenario(Term):
             include_init_phase (bool): whether use initial phase or not
             show_figure (bool): if True, show the result as a figure
             filename (str): filename of the figure, or None (show figure)
-            kwargs: the other keyword arguments will be ignored.
+            kwargs: keyword arguments of ChangeFinder()
 
         Returns:
             None
@@ -241,7 +259,8 @@ class Scenario(Term):
         """
         finder = ChangeFinder(
             self.jhu_data, self.population,
-            country=self.country, province=self.province
+            country=self.country, province=self.province,
+            **kwargs
         )
         if "n_points" in kwargs.keys():
             raise ValueError(
